(function (Drupal) {
  // Build the git command.
  function getGitCommand(text, author) {
    return "git commit -m '" + text + ((author.length) ? "' --author='" + author + "'" : "'");
  }

  let initialised = false;
  Drupal.behaviors.git_commands = {
    attach: function (context) {
      if (!initialised && context === document) {
        initialised = true;
        let issue_title = document.getElementsByTagName('h1');
        let issue_url = document.querySelector('.source a').textContent;
        let copy_button = document.getElementById('git-command-copy');
        let git_command_input = document.getElementById('git-command');
        let git_message_input = document.getElementById('commit-message');
        let git_author_select = document.getElementById('commit-author');
        let available_authors = document.querySelectorAll('.credited .user .git-author');

        // Extract issue number from URL.
        let issue_number = '';
        const extracted_id = parseInt(issue_url.split('/').pop());
        if (extracted_id > 0) {
          issue_number = 'Issue #' + extracted_id + ' ';
        }

        // Populate (or hide) select with possible authors for the commit.
        let by_credited = '';
        if (available_authors.length === 0) {
          git_author_select.parentElement.style.display = 'none';
        }
        else {
          let author_usernames = [];
          available_authors.forEach(function(user) {
            let option = document.createElement('option');
            option.text = user.previousElementSibling.querySelector('.value').textContent;
            option.value = user.textContent;
            git_author_select.add(option);
            author_usernames.push(option.text);
          });
          by_credited = Drupal.t(' by @authors', {'@authors': author_usernames.join(', ')});
        }

        // Set the initial title.
        if (issue_title.length) {
          issue_title = issue_number + issue_title[0].innerText + by_credited;

          git_message_input.value = issue_title;
          git_command_input.value = getGitCommand(issue_title, '');
        }

        // Check if the message is being changed.
        git_message_input.addEventListener('change', function() {
          git_command_input.value = getGitCommand(git_message_input.value, git_author_select.value);
        });

        // Set the author.
        git_author_select.addEventListener('change', function() {
          git_command_input.value = getGitCommand(git_message_input.value, git_author_select.value);
        });

        // Copy to clipboard.
        copy_button.addEventListener('click', function() {
          let text_to_copy = git_command_input.value;
          navigator.clipboard.writeText(text_to_copy).then(() => {
            git_command_input.focus();
          },() => {
            alert(Drupal.t('Could not copy value to clipboard.'));
          });
        });
      }
    }
  };
})(Drupal);
