<?php

namespace Drupal\contribution_records\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for Project Browser.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'contribution_records_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['contribution_records.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('contribution_records.settings');
    $form['allow_dev_sources'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow dev sources.'),
      '#description' => $this->t('Allow fetching data from gitlab1 (non-production) Drupal and GitLab instances.'),
      '#default_value' => $config->get('allow_dev_sources'),
    ];
    $allowed_import_sources = $config->get('allowed_import_sources') ?? '';
    if (is_array($allowed_import_sources) && !empty($allowed_import_sources)) {
      $allowed_import_sources = implode(PHP_EOL, $allowed_import_sources);
    }
    $form['allowed_import_sources'] = [
      '#type' => 'textarea',
      '#required' => TRUE,
      '#title' => $this->t('Allowed sources for special request'),
      '#placeholder' => '1.2.3.4' . PHP_EOL . '172.28.0.9',
      '#description' => nl2br($this->t("Sources listed here will be allowed to make special requests, like raw import requests or querying about metrics.\n Use * to allow any source. Separate multiple values with a line break. Only IPs are allowed.")),
      '#default_value' => $allowed_import_sources,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $value = $form_state->getValue('allowed_import_sources');
    if ($value === '*') {
      return;
    }

    $allowed_import_sources = array_map(
      'trim',
      explode(PHP_EOL, trim($value))
    );
    foreach ($allowed_import_sources as $allowed_import_source) {
      if (!filter_var($allowed_import_source, FILTER_VALIDATE_IP)) {
        $form_state->setErrorByName('allowed_import_sources', $this->t('Source @source is not a valid IP', [
          '@source' => $allowed_import_source,
        ]));
        return FALSE;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $allowed_import_sources = array_map(
      'trim',
      explode(PHP_EOL, trim($form_state->getValue('allowed_import_sources')))
    );
    $this->config('contribution_records.settings')
      ->set('allow_dev_sources', $form_state->getValue('allow_dev_sources'))
      ->set('allowed_import_sources', $allowed_import_sources)
      ->save();
    parent::submitForm($form, $form_state);
  }

}
