<?php

namespace Drupal\contribution_records\Plugin\QueueWorker;

use Drupal\contribution_records\SourceLink;
use Drupal\Core\Queue\QueueWorkerBase;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Defines 'contribution_records_import_queue_worker' queue worker.
 *
 * Run via `drush` like this:
 * `drush queue:run contribution_records_import_queue_worker`.
 *
 * @QueueWorker(
 *   id = "contribution_records_import_queue_worker",
 *   title = @Translation("Import Queue Worker")
 * )
 */
class ContributionRecordImportQueueWorker extends QueueWorkerBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    if (!$this->validateItem($data)) {
      return FALSE;
    }

    /** @var \Drupal\contribution_records\SourceLink $source_link_instance */
    $source_link_instance = \Drupal::classResolver(SourceLink::class);
    $source_link = $source_link_instance->setLink($data['url']);
    if (
      $source_link->isValid(FALSE) &&
      !$source_link->isDuplicated()
    ) {
      $source_link->createContribRecordFromRawData($data);
    }
  }

  /**
   * Validate item array to make sure all key elements are there.
   *
   * @param array $data
   *   Item to validate.
   *
   * @return bool
   *   Whether the item was valid or not.
   */
  protected function validateItem(array $data) {
    if (
      empty($data['url']) ||
      empty($data['title']) ||
      empty($data['credits'])
    ) {
      return FALSE;
    }

    return TRUE;
  }

}
